@@ -88,7 +88,7 @@ impute.rfsrc <- function(formula, data,
         ytry <- min(p - 1, max(25, ceiling(sqrt(p))))
       }
       dots$formula <- as.formula(paste("Unsupervised(", ytry, ") ~ ."))
-      ## TBD TBD splitrule not permissible with unsupervised forests?
+      ## TBD2 splitrule not permissible with unsupervised forests?
       dots$splitrule <- NULL
     }
     else {
@@ -289,6 +289,7 @@ impute.rfsrc <- function(formula, data,
                                                ntree = ntree,
                                                nodesize = nodesize,
                                                nsplit = nsplit,
+                                               perf.type = "none",
                                                fast = fast), dots))}, error = function(e) {NULL})
               ## confirm grow object is non-null in order to proceed
               if (!is.null(grow)) {
